@@ -22,13 +22,11 @@ import json
 import logging
 import os
 import pickle
-import socket
 
 import yaml
-from aiohttp import ClientSession, TCPConnector
+from aiohttp import ClientSession
 from google.auth.credentials import Credentials
 from google.auth.transport.requests import Request
-from google.oauth2 import service_account
 from google_auth_oauthlib.flow import InstalledAppFlow
 
 from .auth import AbstractAuth
@@ -233,11 +231,7 @@ class DeviceWatcherCallback:
 
 async def RunTool(args, user_creds: Credentials):
     """Run the command."""
-    conn = TCPConnector(
-        family=socket.AF_INET,
-        verify_ssl=False,
-    )
-    async with ClientSession(connector=conn) as client:
+    async with ClientSession() as client:
         auth = Auth(client, user_creds, API_URL)
         api = GoogleNestAPI(auth, args.project_id)
 
